{-# LANGUAGE EmptyDataDecls #-}
module OpenCascade.Font.Types 
( BRepFont
, BRepTextBuilder
) where

data BRepFont
data BRepTextBuilder 